==> deepin-camera_1.1.2.orig.tar.xz: deepin-camera-1.1.2/src/translations/deepin-camera_bo.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bo">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>བཪྙན་ཟློས་ཕབ་བཞིན་པས། ཁ་རྒྱག་གམ།</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>ཡིག་ཁུག་ཁ་ཕྱེ།</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>སྒྲིག་འགོད།</translation>
    </message>
    <message>
        <source>None</source>
        <translation>མེད། </translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>འདོར་བ།</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>ཁ་རྒྱག</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>འདྲ་བཤུས།</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>སུབ་པ།</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>ཡིག་ཁུག་ཁ་ཕྱེ།</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>པར་འདེབས། </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>ཁྱེད་ལ་ཡིག་ཁུག་འདི་སུབ་པའི་དབང་ཆ་མེད།</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>ཁ་རྒྱག</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">ཡིག་ཁུག་ཕན་མེད།</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>ཡིག་ཁུག་ཁ་ཕྱེ།</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>སྒྲིག་འགོད།</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>རྨང་གཞིའི་སྒྲིག་འགོད། </translation>
    </message>
    <message>
        <source>File location</source>
        <translation>ཉར་བའི་འགྲོ་ལམ།</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>པར་ལེན་སྒྲིག་འགོད། </translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>བསྟུད་མར་ལེན་པ།</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>དུས་འགྱངས་པར་ལེན་གྱི་སྒྲིག་འགོད།</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>ཕྱིར་འདོན་སྒྲིག་འགོད།</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>ཕྱིར་འདོན་རྣམ་གཞག</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>རྐང་4</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>རྐང་10</translation>
    </message>
    <message>
        <source>None</source>
        <translation>མེད། </translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>པར་ཆས།</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>པར་ཆས་ནི་སྤྱོད་ཐབས་བདེ་བའི་པར་ལེན་ཡོ་བྱད་ཞིག་ཡིན་པ་དང་།པར་ལེན་དང་བཪྙན་ཕབ་སོགས་བྱེད་ནུས་མངོན་གྱུར་བྱེད་ཐུབ།</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>ཡིག་ཆ་ཉར་ཚགས་བྱས་མེད།</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">ཉར་ཚགས་བྱེད་ཡུལ།</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>འདྲ་པར། </translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>བཪྙན་ཟློས། </translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>འབྱེད་ཕྱོད་སྒྲིག་འགོད།</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>འབྱེད་ཕྱོད། </translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>པར་ཉར་ས། </translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>བརྙན་འཕྲིན་ཉར་ས། </translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>སྒྲ་ནུས། </translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>པར་ཆས།</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>སྒྲིག་འགོད།</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>ཕབ་ལེན་བྱེད་མཚམས་འཇོག་པ།</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>འདྲ་བཤུས།</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>སུབ་པ།</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>ཁ་འབྱེད། </translation>
    </message>
    <message>
        <source>Print</source>
        <translation>པར་འདེབས། </translation>
    </message>
    <message>
        <source>Help</source>
        <translation>རོགས་རམ། </translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>མྱུར་མཐེབ་མངོན་སྟོན། </translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>པར་ལེན་མཚམས་འཇོག་པ།</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>འདེམས་བྱང་གཡས་མཐེབ་འགོ་སློང་། </translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation>པར་ལེན། </translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>བཪྙན་ཟློས་ཕབ་ལེན། </translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>པར་ལེན་མཚམས་འཇོག་པ།</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>མེད། </translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>པར་ལེན་སྒྲིག་ཆས་མཐུད་མེད།</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>པར་ལེན་སྒྲིག་ཆས་སྤྱོད་བཞིན་ཡོད།</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>ཕབ་ལེན་བྱེད་མཚམས་འཇོག་པ།</translation>
    </message>
</context>
</TS>

==> deepin-camera_1.3.7.1.orig.tar.xz: deepin-camera-1.3.7.1/src/translations/deepin-camera_bo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="bo" version="2.1">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>བཪྙན་ཟློས་ཕབ་བཞིན་པས། ཁ་རྒྱག་གམ།</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">ཡིག་ཁུག་ཁ་ཕྱེ།</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>སྒྲིག་འགོད།</translation>
    </message>
    <message>
        <source>None</source>
        <translation>མེད། </translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>པར་ལེན།</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>བཪྙན་ལེན།</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>པར་ལེན་ཤེལ་སྒོ་བརྗེ་བ།</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>འདོར་བ།</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>ཁ་རྒྱག</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>འདྲ་བཤུས།</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>སུབ་པ།</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>ཡིག་ཁུག་ཁ་ཕྱེ།</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>པར་འདེབས། </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>ཁྱེད་ལ་ཡིག་ཁུག་འདི་སུབ་པའི་དབང་ཆ་མེད།</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>ཁ་རྒྱག</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">ཡིག་ཁུག་ཕན་མེད།</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>ཡིག་ཁུག་ཁ་ཕྱེ།</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>སྒྲིག་འགོད།</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>རྨང་གཞིའི་སྒྲིག་འགོད། </translation>
    </message>
    <message>
        <source>File location</source>
        <translation>ཉར་བའི་འགྲོ་ལམ།</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>པར་ལེན་སྒྲིག་འགོད། </translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>བསྟུད་མར་ལེན་པ།</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>དུས་འགྱངས་པར་ལེན་གྱི་སྒྲིག་འགོད།</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>ཕྱིར་འདོན་སྒྲིག་འགོད།</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>ཕྱིར་འདོན་རྣམ་གཞག</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>རྐང་4</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>རྐང་10</translation>
    </message>
    <message>
        <source>None</source>
        <translation>མེད། </translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>པར་ཆས།</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>པར་ཆས་ནི་སྤྱོད་ཐབས་བདེ་བའི་པར་ལེན་ཡོ་བྱད་ཞིག་ཡིན་པ་དང་།པར་ལེན་དང་བཪྙན་ཕབ་སོགས་བྱེད་ནུས་མངོན་གྱུར་བྱེད་ཐུབ།</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>ཡིག་ཆ་ཉར་ཚགས་བྱས་མེད།</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">ཉར་ཚགས་བྱེད་ཡུལ།</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>འདྲ་པར། </translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>བཪྙན་ཟློས། </translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>འབྱེད་ཕྱོད་སྒྲིག་འགོད།</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>འབྱེད་ཕྱོད། </translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>པར་ཉར་ས། </translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>བརྙན་འཕྲིན་ཉར་ས། </translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>སྒྲ་ནུས། </translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>ཤེལ་བཪྙན་རྣམ་པ།</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>འཁྱུག་སྒྲོན།</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>པར་ཆས།</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>སྒྲིག་འགོད།</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>ཕབ་ལེན་བྱེད་མཚམས་འཇོག་པ།</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>འདྲ་བཤུས།</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>སུབ་པ།</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>ཁ་འབྱེད། </translation>
    </message>
    <message>
        <source>Print</source>
        <translation>པར་འདེབས། </translation>
    </message>
    <message>
        <source>Help</source>
        <translation>རོགས་རམ། </translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>མྱུར་མཐེབ་མངོན་སྟོན། </translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>པར་ལེན་མཚམས་འཇོག་པ།</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>འདེམས་བྱང་གཡས་མཐེབ་འགོ་སློང་། </translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">པར་ལེན། </translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">བཪྙན་ཟློས་ཕབ་ལེན། </translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">པར་ལེན་མཚམས་འཇོག་པ།</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>མེད། </translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>ཚད་ལྡན།</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>མངོན་གསལ་དོད་པོ།</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>མེའི་མདོག</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>ཆུའི་མདོག</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>སྔ་ཉམས།</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>པར་རྒྱག་པ།</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>སྐྱ་མདོག</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>དཀར་ནག</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>འཁྱུག་སྒྲོན།</translation>
    </message>
    <message>
        <source>On</source>
        <translation>སྒོ་ཕྱེ།</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>སྒོ་རྒྱག</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>དུས་འགྱངས་པར་ལེན།</translation>
    </message>
    <message>
        <source>None</source>
        <translation>མེད། </translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>གཙང་མ་བཟོས་པ།</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>འོད་ཕོག</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>པར་ལེན་སྒྲིག་ཆས་མཐུད་མེད།</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>པར་ལེན་སྒྲིག་ཆས་སྤྱོད་བཞིན་ཡོད།</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">ཕབ་ལེན་བྱེད་མཚམས་འཇོག་པ།</translation>
    </message>
</context>
</TS>
